<!-- pyOpenRPA documentation master file, created by
sphinx-quickstart on Sat Dec 19 23:59:00 2020.
You can adapt this file completely to your liking, but it should at least
contain the root `toctree` directive. -->
# Welcome to pyOpenRPA’s wiki


![image](Wiki/ENG_Guide/markdown/img/ModalGuide.png)

*by Ivan Maslov (Russia)*

## Donate

pyOpenRPA is a commercial project.

## About

Dear RPA-tors. Let me congratulate you with great change in the RPA world. Since 2019 the first enterprise level open source RPA platform is here!

pyOpenRPA is absolutely open source commercial project. Hosted by LLC PYOPENRPA (RUSSIA)

The pyOpenRPA - free, fast and reliable
Powerful OpenSource RPA tool for business (based on python 3). Best performance and absolutely free!

The pyOpenRPA is based on Python and using well known OpenSource solutions such as Selenium, OpenCV, Win32, UI automation and others. Thanks to it we were able to create consolidated platform with all possible features.
The pyOpenRPA is distributed under the PYOPENRPA open license.
At the time of this writing the pyOpenRPA is successfully using in several big Russian companies. Companies in which it was decided to develop own RPA division with no dependencies on expensive licenses.

## Wiki

Now you can use the following docs:

- ENG Guide HTML [|OPEN GITLAB|](Wiki/ENG_Guide/html/index.html) 
- ENG Guide MarkDown [|OPEN GITLAB|](Wiki/ENG_Guide/markdown/index.md) 
- ENG Guide PDF [|OPEN GITLAB|](Wiki/ENG_Guide/pdf/pyOpenRPA_Guide_ENG.pdf)

- RUS Article: Less cost - no paid RPA [|OPEN HABR|](https://habr.com/ru/post/506766/) 
- RUS Tutorial Desktop UI [|OPEN HABR|](https://habr.com/ru/post/509644/); [|OPEN GITLAB|](Wiki/RUS_Tutorial/DesktopGUI_Habr/README.md)
- RUS Tutorial Web UI [|OPEN HABR|](https://habr.com/ru/post/515310/); [|OPEN GITLAB|](Wiki/RUS_Tutorial/WebGUI_Habr/3.%20WebGUI_Habr.md)
- RUS Leaflet pyOpenRPA v5.pdf [|OPEN GITLAB|](Wiki/RUS_Leaflet/RUS%20Leaflet%20pyOpenRPA%20v5.pdf)

## Copyrights & Contacts
pyOpenRPA is created by Ivan Maslov (Russia). Use it for free only for non-commercial purposes. For commercial purpose please ask pyOpenRPA vendor for license.
My purpose is to create #IT4Business models. 
If you need IT help feel free to contact me.

Ivan Maslov contacts (CEO & FOUNDER): 

- E-mail: Ivan.Maslov@pyOpenRPA.ru
- Skype: MegaFinder
- Web: https://pyopenrpa.ru/
- Telegram: https://t.me/pyopenrpa
- WhatsApp | Telegram: +7 906 722 39 25 | @IvanMaslov